<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\GeneralSettings;


use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class LoginController extends Controller
{
    // This method will show login page for customer
    public function index(){
        return view('account.login');
    }

    public function authenticate(Request $request)
    {
        $rules = [
            'email' => 'required|email',
            'password' => 'required|min:5',
        ];
    
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect()->route('account.login')->withInput()->withErrors($validator);
        } else {
            // Attempt to authenticate the user
            if (Auth::attempt(['email' => $request->email, 'password' => $request->password])) {
                $user = Auth::user();
    
                // Check if the user has 'customer' role
                if ($user->role == 'customer') {
                    return redirect()->route('account.dashboard');
                } else {
                    // Log out the user if they are not a 'customer' and show error message
                    Auth::logout();
                    return redirect()->route('account.login')->with('error', 'Access denied. Only customers can log in.');
                }
            } else {
                return redirect()->route('account.login')->with('error', 'Either email or password is incorrect.');
            }
        }
    }
    


    public function register(){
        $settings = GeneralSettings::first();
        $headerLogoUrl = $settings->header_logo ? asset('storage/' . $settings->header_logo) : null;
        $footerLogoUrl = $settings->footer_logo ? asset('storage/' . $settings->footer_logo) : null;

        return view('account.register',compact('settings','headerLogoUrl','footerLogoUrl'));
    }

    public function processRegister(Request $request){
        $rules = [
            'username' => 'required|min:3',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:5|confirmed',
            'password_confirmation' => 'required',
        ];

        $validator = Validator::make($request->all(),$rules);
        if($validator->fails()){
                return redirect()->route('account.register')->withInput()->withErrors($validator);
        }

        $user = new User();
        $user->name = $request->username;
        $user->email = $request->email; 
        $user->password = Hash::make($request->password);
        $user->role = 'customer';
        $user->save();

        return redirect()->route('account.login')->with('success','You have successfully registered.');
    }


    public function logout(){
        Auth::logout();
        return redirect()->route('account.login');
    }




}
