<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Enquiry;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class CategoryController extends Controller
{
    // Display a list of categories
    public function index()
    {
        // Fetch all categories
        $categories = Category::all();
        $enquries =Enquiry::all();
        $user = Auth::guard('admin')->user();

        return view('backend.admin.category.index', compact('categories','user','enquries'));
    }

    // Show the form to create a new category
    public function create()
    {
        $user = Auth::guard('admin')->user(); // Fetch the logged-in admin user
        $enquries =Enquiry::all();

        return view('backend.admin.category.create',compact('user','enquries'));
    }

    // Store a new category
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'status' => 'required|in:active,inactive',  // Validate status is either active or inactive
        ]);
    
        // Create category
        Category::create([
            'name' => $request->name,
            'status' => $request->status,  // Store the selected status
        ]);
    
        return redirect()->route('categories.index')->with('success', 'Category created successfully.');
    }
    

    // Show the form to edit a category
    public function edit($id)
    {
        $user = Auth::guard('admin')->user(); // Fetch the logged-in admin user
        $enquries =Enquiry::all();

        $category = Category::findOrFail($id);
        return view('backend.admin.category.edit', compact('category','user','enquries'));
    }

    // Update a category
    public function update(Request $request, $id)
    {
        // Validate the request data
        $request->validate([
            'name' => 'required|string|max:255',
        ]);

        // Find and update the category
        $category = Category::findOrFail($id);
        $category->update([
            'name' => $request->name,
            'status' => $request->status ?? 'active', // Update status if provided
        ]);

        // Redirect with a success message
        return redirect()->route('categories.index')->with('success', 'Category updated successfully.');
    }

    // Delete a category
    public function destroy($id)
    {
        $category = Category::findOrFail($id);
        $category->delete();

        return redirect()->route('categories.index')->with('success', 'Category deleted successfully.');
    }

    public function updateStatus(Request $request, $id)
    {
        // Find the category by ID
        $category = Category::findOrFail($id);

        // Toggle the status
        $category->status = ($category->status == 'active') ? 'inactive' : 'active';
        $category->save(); // Save the updated status

        // Redirect back to categories page
        return redirect()->route('categories.index');
    }
}
