<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Enquiry;
use App\Exports\EnquiriesExport;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Maatwebsite\Excel\Facades\Excel;

class EnquiryShowController extends Controller
{
    /**
     * Display the list of enquiries.
     */
    public function index()
    {
        // Fetch all enquiries from the database
        $enquiries = Enquiry::all();
        $user = Auth::guard('admin')->user();
        $enquries = Enquiry::all();

        // Return the view with the enquiries data
        return view('backend/admin/enquries', compact('enquiries', 'user', 'enquries'));
    }

    /**
     * Toggle the status of an enquiry.
     */
    public function toggleStatus($id)
    {
        // Find the enquiry by ID
        $enquiry = Enquiry::findOrFail($id);

        // Toggle the status
        $enquiry->status = $enquiry->status == 'active' ? 'inactive' : 'active';
        $enquiry->save();

        // Redirect back with a success message
        return back()->with('success', 'Enquiry status updated successfully!');
    }

    /**
     * Export enquiries to Excel.
     */
    public function exportExcel()
    {
        return Excel::download(new EnquiriesExport, 'enquiries.xlsx');
    }

    /**
     * Export enquiries to CSV.
     */
    public function exportCSV()
    {
        return Excel::download(new EnquiriesExport, 'enquiries.csv', \Maatwebsite\Excel\Excel::CSV);
    }


    public function fetchNewEnquiries()
{
    // Get the enquiries created in the last 24 hours
    $enquiries = Enquiry::where('created_at', '>=', now()->subDay())->get();

    // Return the data as JSON
    return response()->json([
        'count' => $enquiries->count(),
        'enquiries' => $enquiries
    ]);
}

}
