<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;

use App\Models\Investorcategory;
use App\Models\InvestorContent;
use Illuminate\Http\Request;

class InvestorContentsController extends Controller
{
    public function index()
    {
        $investorContents = InvestorContent::with(['category', 'subcategory'])->get();
        return view('backend.admin.investor_content.index', compact('investorContents'));
    }

    public function create()
    {
        $categories = Investorcategory::whereNull('subcategory_parent_id')->get();
        return view('backend.admin.investor_content.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'investor_category_id' => 'required',
            'type' => 'required|in:pdf,text',
            'title' => 'required|string|max:255',
            'pdf' => 'nullable|file|mimes:pdf|max:2048',
            'content' => 'nullable|string'
        ]);

        $pdfPath = null;
        if ($request->hasFile('pdf')) {
            $pdfPath = $request->file('pdf')->store('pdfs', 'public');
        }

        InvestorContent::create([
            'investor_category_id' => $request->investor_category_id,
            'investor_subcategory_id' => $request->investor_subcategory_id,
            'type' => $request->type,
            'title' => $request->title,
            'pdf' => $pdfPath,
            'content' => $request->content
        ]);

        return redirect()->route('investor-contents.index')->with('success', 'Content added successfully.');
    }

    public function edit(InvestorContent $investorContent)
    {
        $categories = InvestorCategory::whereNull('subcategory_parent_id')->get();
        return view('backend.admin.investor_content.edit', compact('investorContent', 'categories'));
    }

    public function update(Request $request, InvestorContent $investorContent)
    {
        $request->validate([
            'investor_category_id' => 'required',
            'type' => 'required|in:pdf,text',
            'title' => 'required|string|max:255',
            'pdf' => 'nullable|file|mimes:pdf|max:2048',
            'content' => 'nullable|string'
        ]);

        if ($request->hasFile('pdf')) {
            $pdfPath = $request->file('pdf')->store('pdfs', 'public');
            $investorContent->pdf = $pdfPath;
        }

        $investorContent->update([
            'investor_category_id' => $request->investor_category_id,
            'investor_subcategory_id' => $request->investor_subcategory_id,
            'type' => $request->type,
            'title' => $request->title,
            'content' => $request->content
        ]);

        return redirect()->route('investor-contents.index')->with('success', 'Content updated successfully.');
    }

    public function destroy(InvestorContent $investorContent)
    {
        $investorContent->delete();
        return redirect()->route('investor-contents.index')->with('success', 'Content deleted successfully.');
    }

    public function fetchSubcategories(Request $request)
    {
        return response()->json(
            InvestorCategory::where('subcategory_parent_id', $request->category_id)->get()
        );
    }
}
