<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Investor;
use App\Models\Subcategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class InvestorController extends Controller
{
    public function index()
    {
        $investors = Investor::with('subcategory')->get();
        return view('backend.admin.investors.index', compact('investors'));
    }

    public function create()
    {
        $subcategories = Subcategory::all();
        return view('backend.admin.investors.create', compact('subcategories'));
    }



    public function store(Request $request)
    {
        $request->validate([
            'name' => 'nullable|string|max:255',
            'description' => 'nullable|string',
            'subcategory_id' => 'nullable|exists:subcategories,id',
            'image' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
            'pdf' => 'nullable|mimes:pdf|max:10048',
        ]);

        $data = $request->only(['name', 'description', 'subcategory_id']);

        if ($request->hasFile('image')) {
            $data['image'] = $request->file('image')->store('investors', 'public');
        }
        if ($request->hasFile('pdf')) {
            $data['pdf'] = $request->file('pdf')->store('investors', 'public');
        }

        // dd($data); // Ye check karega ki data sahi ja raha hai ya nahi

        Investor::create($data);

        return redirect()->route('investors')->with('success', 'Investor added successfully.');
    }






    public function edit($id)
    {
        $investor = Investor::findOrFail($id);
        $subcategories = Subcategory::all();
        return view('backend.admin.investors.edit', compact('investor', 'subcategories'));
    }

    public function update(Request $request, $id)
    {
        $investor = Investor::findOrFail($id);

        $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'nullable|string',
            'subcategory_id' => 'required|exists:subcategories,id',
            'image' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
            'pdf' => 'nullable|mimes:pdf|max:5048',
        ]);

        $data = $request->only(['name', 'description', 'subcategory_id']);

        if ($request->hasFile('image')) {
            if ($investor->image) {
                Storage::disk('public')->delete($investor->image);
            }
            $data['image'] = $request->file('image')->store('investors', 'public');
        }
        if ($request->hasFile('pdf')) {
            if ($investor->pdf) {
                Storage::disk('public')->delete($investor->pdf);
            }
            $data['pdf'] = $request->file('pdf')->store('investors', 'public');
        }

        $investor->update($data);

        return redirect()->route('investors')->with('success', 'Investor updated successfully.');
    }

    public function destroy($id)
    {
        $investor = Investor::findOrFail($id);

        if ($investor->image) {
            Storage::disk('public')->delete($investor->image);
        }
        if ($investor->pdf) {
            Storage::disk('public')->delete($investor->pdf);
        }

        $investor->delete();
        return redirect()->route('admin.investors.index')->with('success', 'Investor deleted successfully.');
    }
}
