<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Investorcategory;
use App\Models\Subcategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class InvestorcategoryController extends Controller
{
     public function index()
    {
        $categories = InvestorCategory::with('parentCategory')->get();
        return view('backend.admin.investor_cat.index', compact('categories'));
    }

    public function create()
    {
        $categories = InvestorCategory::all();
        return view('backend.admin.investor_cat.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'category' => 'required|string|max:255',
            'subcategory_parent_id' => 'nullable|exists:investorcategories,id',
        ]);

        InvestorCategory::create($request->all());

        return redirect()->route('investorcategories.index')->with('success', 'Category created successfully.');
    }

    public function edit(InvestorCategory $investorcategory)
    {
        $categories = InvestorCategory::where('id', '!=', $investorcategory->id)->get();
        return view('backend.admin.investor_cat.edit', compact('investorcategory', 'categories'));
    }

    public function update(Request $request, InvestorCategory $investorcategory)
    {
        $request->validate([
            'category' => 'required|string|max:255',
            'subcategory_parent_id' => 'nullable|exists:investorcategories,id',
        ]);

        $investorcategory->update($request->all());

        return redirect()->route('investorcategories.index')->with('success', 'Category updated successfully.');
    }

    public function destroy(InvestorCategory $investorcategory)
    {
        $investorcategory->delete();
        return redirect()->route('investorcategories.index')->with('success', 'Category deleted successfully.');
    }
}
