<?php


namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Team;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class OurTeamController extends Controller
{
    // Display a list of all team members
    public function index()
    {
        $teams = Team::latest()->get();
        return view('backend.admin.ourteam.index', compact('teams'));
    }

    // Show form to create a new team member
    public function create()
    {
        return view('backend.admin.ourteam.create');
    }

    // Store a newly created team member
    public function store(Request $request)
    {
        // Validate input fields
        $request->validate([
            'name' => 'required|string|max:255',
            'designation' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        // Upload image if provided
        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('team_images', 'public');
        } else {
            $imagePath = null;
        }

        // Create a new team member record
        Team::create([
            'name' => $request->name,
            'designation' => $request->designation,
            'image' => $imagePath,
        ]);

        return redirect()->route('teams.index')->with('success', 'Team Member Added Successfully.');
    }

    // Show form to edit an existing team member
    public function edit($id)
    {
        $teams = Team::findOrFail($id);
        return view('backend.admin.ourteam.edit', compact('teams'));
    }

    // Update an existing team member
    public function update(Request $request, $id)
    {
        $teamMember = Team::findOrFail($id);

        // Validate input fields
        $request->validate([
            'name' => 'required|string|max:255',
            'designation' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        // Check if a new image is uploaded
        if ($request->hasFile('image')) {
            // Delete old image if exists
            if ($teamMember->image) {
                Storage::disk('public')->delete($teamMember->image);
            }
            // Upload new image
            $imagePath = $request->file('image')->store('team_images', 'public');
        } else {
            $imagePath = $teamMember->image;
        }

        // Update team member record
        $teamMember->update([
            'name' => $request->name,
            'designation' => $request->designation,
            'image' => $imagePath,
        ]);

        return redirect()->route('teams.index')->with('success', 'Team Member Updated Successfully.');
    }

    // Delete a team member
    public function destroy($id)
    {
        $teamMember = Team::findOrFail($id);

        // Delete image from storage if exists
        if ($teamMember->image) {
            Storage::disk('public')->delete($teamMember->image);
        }

        // Delete team member record
        $teamMember->delete();
        return redirect()->route('teams.index')->with('success', 'Team Member Deleted Successfully.');
    }
}



