<?php
namespace App\Http\Controllers\admin;


use App\Http\Controllers\Controller;

use Illuminate\Http\Request;
use App\Models\Product;
use App\Models\Category;
use Illuminate\Support\Str;

class ProductController extends Controller
{
    public function index()
    {
        $products = Product::with('category')->get();
        return view('backend.admin.products.index', compact('products'));
    }

    public function create()
    {
        $categories = Category::all();
        return view('backend.admin.products.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'heading' => 'required|string|max:255|unique:products,heading',
            'category_id' => 'required|exists:categories,id',
            'image' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $imagePath = null;
        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('products', 'public');
        }

        Product::create([
            'heading' => $request->heading,
            'slug' => Str::slug($request->heading),
            'category_id' => $request->category_id,
            'description' => $request->description,
            'image' => $imagePath,
        ]);

        return redirect()->route('admin.products.index')->with('success', 'Product added successfully');
    }

   
    public function edit($id)
    {
        $product = Product::findOrFail($id);
        $categories = Category::all();
        return view('backend.admin.products.edit', compact('product', 'categories'));
    }
    
    public function update(Request $request, $id)
    {
        $product = Product::findOrFail($id);
    
        $request->validate([
            'heading' => 'required|string|max:255',
            'category_id' => 'required|exists:categories,id',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'description' => 'nullable|string',
        ]);
    
        // Purani Image Ko Delete Karna (Agar Nayi Upload Ho Rahi Hai)
        if ($request->hasFile('image')) {
            if ($product->image) {
                Storage::disk('public')->delete($product->image);
            }
            $imagePath = $request->file('image')->store('products', 'public');
            $product->image = $imagePath;
        }
    
        $product->update([
            'heading' => $request->heading,
            'slug' => Str::slug($request->heading),
            'category_id' => $request->category_id,
            'description' => $request->description,
        ]);
    
        return redirect()->route('admin.products.index')->with('success', 'Product updated successfully');
    }
    



    public function destroy(Product $product)
    {
        if ($product->image) {
            \Storage::delete('public/' . $product->image);
        }
        $product->delete();
        return redirect()->route('admin.products.index')->with('success', 'Product deleted successfully');
    }
}
