<?php

// app/Http/Controllers/Admin/SliderController.php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Slider;
use App\Models\Enquiry;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
class SliderController extends Controller
{
    // Display all sliders
    public function index()
    {
        $sliders = Slider::all();  // Fetch all sliders
        $user = Auth::guard('admin')->user();
        $enquries =Enquiry::all();

        return view('backend.admin.slider.index', compact('sliders','user','enquries'));
    }

    // Show the form to create a new slider
    public function create()
    {   
        $enquries =Enquiry::all();
        $user = Auth::guard('admin')->user();

        return view('backend.admin.slider.create', compact('user','enquries'));
    }

    // Store a newly created slider in the database
    public function store(Request $request)
    {
        $request->validate([
            'heading' => 'required|string|max:255',
            'subheading' => 'required|string|max:255',
            'url' => 'required|url',
            'background_image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $slider = new Slider();
        $slider->heading = $request->heading;
        $slider->subheading = $request->subheading;
        $slider->url = $request->url;

        // Handle image upload
        if ($request->hasFile('background_image')) {
            $imagePath = $request->file('background_image')->store('slider_images', 'public');
            $slider->background_image = $imagePath;
        }

        $slider->save();

        return redirect()->route('admin.slider.index')->with('success', 'Slider added successfully!');
    }

    // Show the form to edit an existing slider
    public function edit(Slider $slider)
    {
        $user = Auth::guard('admin')->user(); // Fetch the logged-in admin user
        $enquries =Enquiry::all();

        return view('backend.admin.slider.edit', compact('slider','user','enquries'));
    }

    // Update the specified slider in the database
    public function update(Request $request, Slider $slider)
    {
        $request->validate([
            'heading' => 'required|string|max:255',
            'subheading' => 'required|string|max:255',
            'url' => 'required|url',
            'background_image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $slider->heading = $request->heading;
        $slider->subheading = $request->subheading;
        $slider->url = $request->url;

        // Handle image upload if a new image is uploaded
        if ($request->hasFile('background_image')) {
            $imagePath = $request->file('background_image')->store('slider_images', 'public');
            $slider->background_image = $imagePath;
        }

        $slider->save();

        return redirect()->route('admin.slider.index')->with('success', 'Slider updated successfully!');
    }

    // Delete the specified slider
    public function destroy(Slider $slider)
    {
        $slider->delete();
        return redirect()->route('admin.slider.index')->with('success', 'Slider deleted successfully!');
    }
}
