<?php


namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\SubCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class SubCategoryController extends Controller
{
    public function index()
    {
        $subcategories = SubCategory::all();
        return view('backend.admin.subcategory.index', compact('subcategories'));
    }

    public function create()
    {
        return view('backend.admin.subcategory.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'status' => 'required|in:active,inactive',
        ]);

        // इमेज को सही तरीके से स्टोर करें
        $imagePath = $request->file('image')->store('subcategory_images', 'public');

        // SubCategory में डेटा सेव करें
        SubCategory::create([
            'name' => $request->name,
            'image' => $imagePath, // इमेज का पाथ सेव करें
            'status' => $request->status,
        ]);

        return redirect()->route('admin.subcategories')->with('success', 'Subcategory created successfully.');
    }

    public function edit($id)
    {
        $subcategory = SubCategory::findOrFail($id);
        return view('backend.admin.subcategory.edit', compact('subcategory'));
    }

    public function update(Request $request, $id)
    {
        $subcategory = SubCategory::findOrFail($id);

        $request->validate([
            'name' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'status' => 'required|in:active,inactive',
        ]);

        if ($request->hasFile('image')) {
            if ($subcategory->image) {
                Storage::disk('public')->delete($subcategory->image);
            }

            $imagePath = $request->file('image')->store('subcategory_images', 'public');
            $subcategory->image = $imagePath;
        }

        $subcategory->name = $request->name;
        $subcategory->status = $request->status;
        $subcategory->save();

        return redirect()->route('admin.subcategories')->with('success', 'Subcategory updated successfully.');
    }

    public function destroy($id)
    {
        $subcategory = SubCategory::findOrFail($id);

        if ($subcategory->image) {
            Storage::disk('public')->delete($subcategory->image);
        }

        $subcategory->delete();
        return redirect()->route('admin.subcategories')->with('success', 'Subcategory deleted successfully.');
    }
}
