<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Testimonial;
use App\Models\Enquiry;

use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class TestimonialController extends Controller
{
    public function index()
    {
        $testimonials = Testimonial::all();
        $user = Auth::guard('admin')->user();
        $enquries =Enquiry::all();

        return view('backend.admin.testimonials.index', compact('testimonials','user','enquries'));
    }

    public function create()
    {
        $user = Auth::guard('admin')->user(); // Fetch the logged-in admin user
        $enquries =Enquiry::all();

        return view('backend.admin.testimonials.create',compact('user','enquries'));
    }

    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'name' => 'required|string|max:255',
            'paragraph' => 'required|string',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,svg|max:5048', // Only a single image allowed
        ]);

        // Handle the image upload
        $imagePath = null;
        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('testimonials', 'public');
        }

        // Create the testimonial
        $testimonial = Testimonial::create([
            'name' => $request->name,
            'paragraph' => $request->paragraph,
            'image' => $imagePath, // Store single image path
        ]);

        return redirect()->route('admin.testimonials.index')->with('success', 'Testimonial created successfully.');
    }

    public function edit($id)
    {
        $user = Auth::guard('admin')->user(); // Fetch the logged-in admin user
        $enquries =Enquiry::all();

        $testimonial = Testimonial::findOrFail($id);
        return view('backend.admin.testimonials.edit', compact('testimonial','user','enquries'));
    }

    public function update(Request $request, $id)
    {
        // Validate the request
        $request->validate([
            'name' => 'required|string|max:255',
            'paragraph' => 'required|string',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,svg|max:5048', // Only a single image allowed
        ]);

        $testimonial = Testimonial::findOrFail($id);

        // Handle image upload (remove old image if new one is uploaded)
        $imagePath = $testimonial->image; // Keep the old image by default
        if ($request->hasFile('image')) {
            // Delete the old image from storage
            if ($imagePath) {
                Storage::disk('public')->delete($imagePath);
            }

            // Store the new image
            $imagePath = $request->file('image')->store('testimonials', 'public');
        }

        // Update the testimonial
        $testimonial->update([
            'name' => $request->name,
            'paragraph' => $request->paragraph,
            'image' => $imagePath, // Update the image path
        ]);

        return redirect()->route('admin.testimonials.index')->with('success', 'Testimonial updated successfully.');
    }

    public function destroy($id)
    {
        $testimonial = Testimonial::findOrFail($id);

        // Delete the image from storage
        $imagePath = $testimonial->image;
        if ($imagePath) {
            Storage::disk('public')->delete($imagePath);
        }

        // Delete the testimonial from the database
        $testimonial->delete();

        return redirect()->route('admin.testimonials.index')->with('success', 'Testimonial deleted successfully.');
    }
}
