<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\TrainingAndDevelopment;
use Illuminate\Http\Request;

class TrainingAndDevelopmentController extends Controller
{
    public function index()
    {
        $data = TrainingAndDevelopment::all();
        return view('backend.admin.training.index', compact('data'));
    }

    public function create()
    {
        return view('backend.admin.training.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'description' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048'
        ]);

        $imagePath = $request->file('image')->store('training', 'public');

        TrainingAndDevelopment::create([
            'description' => $request->description,
            'image' => $imagePath
        ]);

        return redirect()->route('admin.training.index')->with('success', 'Added Successfully');
    }

    public function edit($id)
    {
        $data = TrainingAndDevelopment::findOrFail($id);
        return view('backend.admin.training.edit', compact('data'));
    }

    public function update(Request $request, $id)
    {
        $request->validate(['description' => 'required']);

        $data = TrainingAndDevelopment::findOrFail($id);
        $imagePath = $data->image;

        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('training', 'public');
        }

        $data->update(['description' => $request->description, 'image' => $imagePath]);
        return redirect()->route('admin.training.index')->with('success', 'Updated Successfully');
    }

    public function destroy($id)
    {
        $data = TrainingAndDevelopment::findOrFail($id);
        $data->delete();
        return redirect()->route('admin.training.index')->with('success', 'Deleted Successfully');
    }
}