<?php
namespace App\Http\Controllers\frontend;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Enquiry;
use App\Mail\EnquirySubmitted;
use Illuminate\Support\Facades\Mail;

class EnquaryFormController extends Controller
{
    public function store(Request $request)
    {
        // Validation: Accepts the full phone number (including country code)
        $validated = $request->validate([
            'Name' => 'required|string|max:255',
            'Email' => 'required|email|max:255',
            'MobileNo' => 'required|string|max:20',  // Allow full phone number (with country code)
            'Questions' => 'required|string',
            'location' => 'nullable|string',
            // 'g-recaptcha-response' => 'required|captcha',  // If you need Google reCAPTCHA
        ]);

        // Storing data in the database
        $enquiry = Enquiry::create([
            'name' => $request->Name,
            'email' => $request->Email,
            'mobile_no' => $request->MobileNo,  // Store the full phone number (with country code)
            'questions' => $request->Questions,
            'location' => $request->location, 
        ]);

        // If successful
        if ($enquiry) {
            // Sending email
            Mail::to($request->Email)->send(new EnquirySubmitted($enquiry));

            return back()->with('success', 'Enquiry submitted successfully! Check your email for details.');
        } else {
            return back()->with('error', 'Failed to submit your enquiry. Please try again.');
        }
    }
}
