@extends('backend.layouts.adminlayouts')

@section('content')
    <main id="main" class="main">


        @if (session('error'))
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                {{ session('error') }}
                <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        @endif
        <section class="section">
            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Create Blog</h5>

                            <form id="quill-form" action="{{ route('blogs.store') }}" method="POST"
                                enctype="multipart/form-data">
                                @csrf

                                <!-- Title Field -->
                                <div class="row mb-3">
                                    <label for="title" class="col-sm-2 col-form-label">Blog Title:</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" id="title" name="title" required>
                                    </div>
                                </div>

                                <!-- Author Name Field -->
                                <div class="row mb-3">
                                    <label for="author" class="col-sm-2 col-form-label">Author Name:</label>
                                    <div class="col-sm-10">
                                        <input type="text" class="form-control" id="author" name="author" required>
                                    </div>
                                </div>

                                <!-- Category Field -->
                                <div class="row mb-3">
                                    <label for="category" class="col-sm-2 col-form-label">Category:</label>
                                    <div class="col-sm-10">
                                        <select class="form-control" id="category" name="category" required>
                                            @foreach ($categories as $category)
                                                <option value="{{ $category->id }}">{{ $category->name }}</option>
                                            @endforeach
                                        </select>
                                    </div>
                                </div>

                                <!-- Publish Date Field -->
                                <div class="row mb-3">
                                    <label for="publish_date" class="col-sm-2 col-form-label">Publish Date:</label>
                                    <div class="col-sm-10">
                                        <input type="date" class="form-control" id="publish_date" name="publish_date"
                                            required>
                                    </div>
                                </div>

                                <!-- Content Field -->
                                {{-- <div class="row mb-3 ">
                                <label for="content" class="col-sm-2 col-form-label">Content:</label>
                                <div id="quill-editor" class="col-sm-10 quill-editor-full">
                                    <textarea class="form-control" id="content" name="content" required></textarea>
                                </div>
                                @error('content')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                            </div>  --}}




                                <!-- Status Field -->
                                <div class="row mb-3">
                                    <label for="status" class="col-sm-2 col-form-label">Status:</label>
                                    <div class="col-sm-10">
                                        <select class="form-control" id="status" name="status" required>
                                            <option value="active">Active</option>
                                            <option value="inactive">Inactive</option>
                                        </select>
                                    </div>
                                </div>

                                <!-- Blog Image Field -->
                                <div class="mb-3">
                                    <label for="blog_img" class="form-label">Blog Images</label>
                                    <input type="file" id="blog_img" name="images[]" accept="image/*" multiple
                                        class="form-control">
                                </div>

                                <!-- Image Previews -->
                                <div id="image-previews" class="d-flex flex-wrap gap-2"
                                    style="max-height: 400px; overflow-y: auto;">
                                    <!-- Image previews will appear here -->
                                </div>
                                <h5><b>Content</b></h5>
                                <div class="row mb-3">
                                    <div class="col-sm-12">
                                        <!-- Quill Editor Container -->
                                        <div id="quill-editor" class="quill-editor-full mb-3">{!! $setting->content ?? '' !!}</div>

                                        <!-- Hidden Textarea for Form Submission -->
                                        <textarea name="content" id="hidden-content" style="display: none;"
                                            class="form-control @error('content') is-invalid @enderror"></textarea>

                                        @error('content')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                    </div>
                                </div>


                                {{-- SEO form code here  --}}
                                <h5 class="card-title" style="margin-top:6rem">SEO Content</h5>
                                <div class="row mb-3">
                                    <!-- Meta Keywords -->
                                    <div class="col-md-12">
                                        <label for="seoKeywords" class="form-label">SEO Keywords</label>
                                        <input id="seoKeywords" name="seo_keywords"
                                            placeholder="Type and press space or enter" class="form-control"
                                            style="padding: 10px 15px; height: auto;" />
                                    </div>
                                    <!-- Meta Title -->
                                    <div class="col-md-6 mt-3">
                                        <label for="seo_title" class="form-label">Meta Title:</label>
                                        <input type="text" class="form-control @error('seo_title') is-invalid @enderror"
                                            id="seo_title" name="seo_title" placeholder="Enter SEO Title" required
                                            value="{{ old('seo_title') }}">
                                        @error('seo_title')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                    </div>
                                    <!-- Meta Description -->
                                    <div class="col-md-6 mt-3">
                                        <label for="seo_description" class="form-label">Meta Description:</label>
                                        <textarea class="form-control @error('seo_description') is-invalid @enderror" id="seo_description"
                                            name="seo_description" rows="4" placeholder="Enter SEO Description" required>{{ old('seo_description') }}</textarea>
                                        @error('seo_description')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                    </div>
                                </div>

                                <h5 class="card-title">FAQ Section</h5>
                                <div class="faq-container">
                                    <div class="row mb-3 faq-item">
                                        <!-- Question Field -->
                                        <div class="col-md-5">
                                            <label for="question" class="form-label">FAQ Question</label>
                                            <input type="text" class="form-control" name="faqs[][question]"
                                                placeholder="Enter Question" required>
                                        </div>
                                        <!-- Answer Field -->
                                        <div class="col-md-6">
                                            <label for="answer" class="form-label">FAQ Answer</label>
                                            <textarea class="form-control" name="faqs[][answer]" rows="4" placeholder="Enter Answer" required></textarea>
                                        </div>
                                        <!-- Delete Button (X) -->
                                        <div class="col-md-1">
                                            <button type="button" class="btn btn-danger delete-faq-btn"
                                                style="margin-top: 25px;">X</button>
                                        </div>
                                    </div>
                                </div>


                                <!-- Button to Add FAQ -->
                                <button type="button" class="btn btn-success" id="add-faq-btn">Add FAQ</button>





                                <!-- Submit Button -->
                                <div class="row" style="margin-top: 6rem;">
                                    <div class="col-sm-10 offset-sm-2">
                                        <button type="submit" class="btn btn-primary">Create Blog</button>
                                    </div>

                                </div>
                            </form>

                        </div>
                    </div>
                </div>
            </div>
        </section>
    </main>

    <!-- Include Tagify Script -->
    <script src="https://cdn.jsdelivr.net/npm/@yaireo/tagify"></script>
    <script>
        // The DOM element you wish to replace with Tagify
        var input = document.querySelector('#seoKeywords');

        // Initialize Tagify on the input element
        new Tagify(input, {
            enforceWhitelist: false, // Allow any value to be added
            delimiters: ", ", // Tag creation on space or enter
            dropdown: {
                enabled: 0, // Disable dropdown suggestions
            },
            maxTags: Infinity, // Allow unlimited tags
        });

        // Adjust CSS for center-aligned tags and balanced padding
        document.querySelector('.tagify').style.cssText += `
       display: flex;
       align-items: center; /* Center-align tags vertically */
       flex-wrap: wrap; /* Enable wrapping of tags */
       min-height: 50px; /* Maintain a minimum height */
       padding: 8px 12px; /* Balanced padding */
       box-sizing: border-box; /* Include padding in height */
   `;

        document.querySelector('.tagify__input').style.cssText += `
       margin-top: 0; /* Remove extra top margin */
   `;
    </script>

    {{-- FAQ --}}
    <script>
        // Add new FAQ item
        document.getElementById('add-faq-btn').addEventListener('click', function() {
            const faqContainer = document.querySelector('.faq-container');
            const newFaqItem = document.createElement('div');
            newFaqItem.classList.add('row', 'mb-3', 'faq-item');
            newFaqItem.innerHTML = `
       <div class="col-md-5">
           <label for="question" class="form-label">FAQ Question</label>
           <input type="text" class="form-control" name="faqs[][question]" placeholder="Enter Question" required>
       </div>
       <div class="col-md-6">
           <label for="answer" class="form-label">FAQ Answer</label>
           <textarea class="form-control" name="faqs[][answer]" rows="4" placeholder="Enter Answer" required></textarea>
       </div>
       <div class="col-md-1">
           <button type="button" class="btn btn-danger delete-faq-btn" style="margin-top: 25px;">X</button>
       </div>
   `;
            faqContainer.appendChild(newFaqItem);
        });

        // Delete FAQ item
        document.querySelector('.faq-container').addEventListener('click', function(e) {
            if (e.target && e.target.classList.contains('delete-faq-btn')) {
                e.target.closest('.faq-item').remove();
            }
        });
    </script>




    <script>
        $(document).ready(function() {
            var quill = new Quill('#quill-editor', {
                theme: 'snow',
                placeholder: 'Write content here...',
                modules: {
                    toolbar: [
                        ['bold', 'italic'],
                        ['link']
                    ]
                }
            });

            $(document).on('submit', '#quill-form', function() {
                var content = quill.root.innerHTML;
                $('#hidden-content').val(content);
            });
        });
    </script>



    <script>
        // Handle multiple file selection and preview
        document.getElementById('blog_img').addEventListener('change', function(event) {
            var files = event.target.files;
            var previewContainer = document.getElementById('image-previews');

            // Clear previous previews
            previewContainer.innerHTML = '';

            // Loop through selected files and display preview with remove option
            Array.from(files).forEach(function(file) {
                var reader = new FileReader();

                reader.onload = function(e) {
                    // Create container for the image and remove button
                    var imageContainer = document.createElement('div');
                    imageContainer.style.position = 'relative';
                    imageContainer.style.margin = '5px';

                    // Create the image element
                    var imgTag = document.createElement('img');
                    imgTag.src = e.target.result;
                    imgTag.style.width = '100px';
                    imgTag.style.height = '100px';
                    imgTag.style.border = '1px solid #ddd';
                    imgTag.style.borderRadius = '5px';
                    imgTag.style.objectFit = 'cover';

                    // Create the remove button
                    var removeButton = document.createElement('button');
                    removeButton.innerText = 'X';
                    removeButton.style.position = 'absolute';
                    removeButton.style.top = '0';
                    removeButton.style.right = '0';
                    removeButton.style.backgroundColor = 'rgba(255, 0, 0, 0.7)';
                    removeButton.style.color = 'white';
                    removeButton.style.border = 'none';
                    removeButton.style.borderRadius = '50%';
                    removeButton.style.width = '20px';
                    removeButton.style.height = '20px';
                    removeButton.style.fontSize = '16px';
                    removeButton.style.cursor = 'pointer';

                    // Add event listener to remove the preview on click
                    removeButton.onclick = function() {
                        imageContainer.remove();
                    };

                    // Append image and remove button to the container
                    imageContainer.appendChild(imgTag);
                    imageContainer.appendChild(removeButton);

                    // Append the image container to the preview section
                    previewContainer.appendChild(imageContainer);
                };

                reader.readAsDataURL(file); // Read the selected file as a data URL
            });
        });
    </script>
@endsection
