@extends('backend.layouts.adminlayouts')

@section('content')

<main id="main" class="main">

@if(session('error'))
<div class="alert alert-danger alert-dismissible fade show" role="alert">
    {{ session('error') }}
    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
</div>
@endif
    <section class="section">
        <div class="row">
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Edit Blog</h5>
                        <form id="quill-form" action="{{ route('blogs.update', $blog->id) }}" method="POST" enctype="multipart/form-data">
                            @csrf
                            @method('PUT')

                            <!-- Title Field -->
                            <div class="row mb-3">
                                <label for="title" class="col-sm-2 col-form-label">Title:</label>
                                <div class="col-sm-10">
                                    <input type="text" class="form-control" id="title" name="title" value="{{ old('title', $blog->title) }}" required>
                                </div>
                            </div>

                            <!-- Category Field -->
                            <div class="row mb-3">
                                <label for="category" class="col-sm-2 col-form-label">Category:</label>
                                <div class="col-sm-10">
                                    <select class="form-control" id="category" name="category" required>
                                        @foreach ($categories as $category)
                                            <option value="{{ $category->id }}" {{ $blog->category_id == $category->id ? 'selected' : '' }}>
                                                {{ $category->name }}
                                            </option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>

                            {{-- <!-- Content Field -->
                            <div class="row mb-3">
                                <label for="content" class="col-sm-2 col-form-label">Content:</label>
                                <div class="col-sm-10">
                                    <textarea class="form-control" id="content" name="content" rows="5" required>{{ old('content', $blog->content) }}</textarea>
                                </div>
                            </div> --}}

                          




                            <!-- Images Field -->
                            <div class="row mb-3">
                                <label for="images" class="col-sm-2 col-form-label">Images:</label>
                                <div class="col-sm-10">
                                    <input type="file" class="form-control" id="images" name="images[]" multiple>
                                    @if ($blog->images)
                                        <div class="mt-3">
                                            <h6>Current Images:</h6>
                                            <div id="image-previews" class="d-flex flex-wrap gap-2">
                                                @foreach (json_decode($blog->images) as $image)
                                                    <div class="image-container position-relative">
                                                        <img src="{{ asset('storage/' . $image) }}" class="img-fluid" style="width: 100px; height: 100px; object-fit: cover;" alt="Current Image" />
                                                        <button type="button" class="btn-remove" onclick="removeImagePreview(this, '{{ $image }}')">X</button>
                                                    </div>
                                                @endforeach
                                            </div>
                                        </div>
                                    @endif
                                </div>
                            </div>

                            <!-- Status Field -->
                            <div class="row mb-3">
                                <label for="status" class="col-sm-2 col-form-label">Status:</label>
                                <div class="col-sm-10">
                                    <select class="form-control" id="status" name="status" required>
                                        <option value="active" {{ $blog->status == 'active' ? 'selected' : '' }}>Active</option>
                                        <option value="inactive" {{ $blog->status == 'inactive' ? 'selected' : '' }}>Inactive</option>
                                    </select>
                                </div>
                            </div>
                            <h5><b>Content</b></h5>
                            <div class="row mb-3">
                                <div class="col-sm-12">
                                    <!-- Quill Editor Container -->
                                    <div id="quill-editor" class="quill-editor-full mb-3">{!! $blog->content ?? '' !!}</div>
    
                                    <!-- Hidden Textarea for Form Submission -->
                                    <textarea name="content" id="hidden-content" style="display: none;" class="form-control @error('content') is-invalid @enderror"> {{ old('content', $blog->content) }}</textarea>
    
                                    @error('content')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>



                    
                            <h5 class="card-title" style="margin-top: 5rem;">SEO Content</h5>
                            <div class="row mb-3">
                               <!-- Meta Keywords -->
                               <div class="col-md-12">
                                  <label for="seoKeywords" class="form-label">SEO Keywords</label>
                                  <input id="seoKeywords" name="seo_keywords" placeholder="Type and press space or enter" class="form-control" style="padding: 10px 15px; height: auto;" value="{{ old('seo_keywords', $blog->seo_keywords) }}" />
                               </div>
                               <!-- Meta Title -->
                               <div class="col-md-6 mt-3">
                                  <label for="seo_title" class="form-label">Meta Title:</label>
                                  <input type="text" class="form-control @error('seo_title') is-invalid @enderror" id="seo_title" name="seo_title" placeholder="Enter SEO Title" required value="{{ old('seo_title', $blog->seo_title) }}">
                                  @error('seo_title')
                                  <div class="invalid-feedback">{{ $message }}</div>
                                  @enderror
                               </div>
                               <!-- Meta Description -->
                               <div class="col-md-6 mt-3">
                                  <label for="seo_description" class="form-label">Meta Description:</label>
                                  <textarea class="form-control @error('seo_description') is-invalid @enderror" id="seo_description" name="seo_description" rows="4" placeholder="Enter SEO Description" required>{{ old('seo_description', $blog->seo_description) }}</textarea>
                                  @error('seo_description')
                                  <div class="invalid-feedback">{{ $message }}</div>
                                  @enderror
                               </div>
                            </div>
       
                            <h5 class="card-title">FAQ Section</h5>
                              
                            <div class="faq-container">
                             @foreach($blog->faqs as $faq)
                             <div class="row mb-3 faq-item">
                                 <!-- Question Field -->
                                 <div class="col-md-5">
                                     <label for="question" class="form-label">FAQ Question</label>
                                     <input type="text" class="form-control" name="faqs[][question]" placeholder="Enter Question" value="{{ old('faqs.question', $faq['question'] ?? '') }}" required>
                                 </div>
                                 
                                 <!-- Answer Field -->
                                 <div class="col-md-6">
                                     <label for="answer" class="form-label">FAQ Answer</label>
                                     <textarea class="form-control" name="faqs[][answer]" rows="4" placeholder="Enter Answer" required>{{ old('faqs.answer', $faq['answer'] ?? '') }}</textarea>
                                 </div>
                                 
                                 <!-- Delete Button (X) -->
                                 <div class="col-md-1">
                                     <button type="button" class="btn btn-danger delete-faq-btn" style="margin-top: 25px;">X</button>
                                 </div>
                             </div>
                             @endforeach
                             
                         </div>
                         <button type="button" class="btn btn-success" id="add-faq-btn">Add FAQ</button>
       







                            <!-- Submit Button -->
                            <div class="row" style="margin-top: 6rem;">
                                <div class="col-sm-10 offset-sm-2">
                                    <button type="submit" class="btn btn-success">Update Blog</button>
                                </div>
                            </div>

                            <!-- Hidden input for removed images -->
                            <input type="hidden" name="removed_images" id="removed_images" value="[]">

                        </form>
                    </div>
                </div>
            </div>
        </div>
    </section>
</main>


<!-- Include Tagify Script -->
<script src="https://cdn.jsdelivr.net/npm/@yaireo/tagify"></script>
<script>
   // The DOM element you wish to replace with Tagify
   var input = document.querySelector('#seoKeywords');
   
   // Initialize Tagify on the input element
   new Tagify(input, {
       enforceWhitelist: false, // Allow any value to be added
       delimiters: ", ", // Tag creation on space or enter
       dropdown: {
           enabled: 0, // Disable dropdown suggestions
       },
       maxTags: Infinity, // Allow unlimited tags
   });
   
   // Adjust CSS for center-aligned tags and balanced padding
   document.querySelector('.tagify').style.cssText += `
       display: flex;
       align-items: center; /* Center-align tags vertically */
       flex-wrap: wrap; /* Enable wrapping of tags */
       min-height: 50px; /* Maintain a minimum height */
       padding: 8px 12px; /* Balanced padding */
       box-sizing: border-box; /* Include padding in height */
   `;
   
   document.querySelector('.tagify__input').style.cssText += `
       margin-top: 0; /* Remove extra top margin */
   `;
</script>

{{-- FAQ --}}
<script>
   // Add new FAQ item
document.getElementById('add-faq-btn').addEventListener('click', function () {
   const faqContainer = document.querySelector('.faq-container');
   const newFaqItem = document.createElement('div');
   newFaqItem.classList.add('row', 'mb-3', 'faq-item');
   newFaqItem.innerHTML = `
       <div class="col-md-5">
           <label for="question" class="form-label">FAQ Question</label>
           <input type="text" class="form-control" name="faqs[][question]" placeholder="Enter Question" required>
       </div>
       <div class="col-md-6">
           <label for="answer" class="form-label">FAQ Answer</label>
           <textarea class="form-control" name="faqs[][answer]" rows="4" placeholder="Enter Answer" required></textarea>
       </div>
       <div class="col-md-1">
           <button type="button" class="btn btn-danger delete-faq-btn" style="margin-top: 25px;">X</button>
       </div>
   `;
   faqContainer.appendChild(newFaqItem);
});

// Delete FAQ item
document.querySelector('.faq-container').addEventListener('click', function (e) {
   if (e.target && e.target.classList.contains('delete-faq-btn')) {
       e.target.closest('.faq-item').remove();
   }
});

</script>



<script>
        $(document).ready(function(){
        var quill = new Quill('#quill-editor', {
            theme: 'snow',
            placeholder: 'Write content here...',
            modules: {
                toolbar: [['bold', 'italic'], ['link']]
            }
        });

        $(document).on('submit','#quill-form',function(){
            var content = quill.root.innerHTML;
            $('#hidden-content').val(content);
        });
    });
</script>


<script>
    // Handle image removal and update the hidden input for removed images
    function removeImagePreview(button, imagePath) {
        // Remove the image preview from the DOM
        button.closest('.image-container').remove();

        // Get current removed images
        let removedImages = JSON.parse(document.getElementById('removed_images').value);

        // Add the removed image path to the array
        removedImages.push(imagePath);

        // Update the hidden input with the new array
        document.getElementById('removed_images').value = JSON.stringify(removedImages);
    }

    // Handle file selection and preview
    document.getElementById('images').addEventListener('change', function(event) {
        var files = event.target.files;
        var previewContainer = document.getElementById('image-previews');

        Array.from(files).forEach(function(file) {
            var reader = new FileReader();

            reader.onload = function(e) {
                var imageContainer = document.createElement('div');
                imageContainer.classList.add('image-container', 'position-relative');
                imageContainer.style.margin = '5px';

                var imgTag = document.createElement('img');
                imgTag.src = e.target.result;
                imgTag.classList.add('img-fluid');
                imgTag.style.width = '100px';
                imgTag.style.height = '100px';
                imgTag.style.objectFit = 'cover';

                var removeButton = document.createElement('button');
                removeButton.type = 'button';
                removeButton.classList.add('btn-remove');
                removeButton.innerText = 'X';
                removeButton.style.position = 'absolute';
                removeButton.style.top = '0';
                removeButton.style.right = '0';
                removeButton.style.backgroundColor = 'rgba(255, 0, 0, 0.7)';
                removeButton.style.color = 'white';
                removeButton.style.border = 'none';
                removeButton.style.borderRadius = '50%';
                removeButton.style.width = '20px';
                removeButton.style.height = '20px';
                removeButton.style.fontSize = '16px';
                removeButton.style.cursor = 'pointer';

                removeButton.onclick = function() {
                    imageContainer.remove();
                };

                imageContainer.appendChild(imgTag);
                imageContainer.appendChild(removeButton);

                previewContainer.appendChild(imageContainer);
            };

            reader.readAsDataURL(file);
        });
    });
</script>

@endsection
