@extends('backend.layouts.adminlayouts')
@section('content')
<main id="main" class="main">
   <div class="pagetitle-container">
      <div class="pagetitle float-left">
         <h1>Blog</h1>
         <nav>
            <ol class="breadcrumb">
               <li class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Home</a></li>
               <li class="breadcrumb-item active">Blog</li>
            </ol>
         </nav>
      </div>
      <div class="button-container float-right">
         <a href="{{ route('blogs.create') }}" class="btn-add-university">
         <i class='bx bx-add-to-queue' style="font-size: 24px;"></i> Add Blogs
         </a>
      </div>
   </div>
   <!-- Success and Error Alerts -->
   @if(session('success'))
   <div class="alert alert-success alert-dismissible fade show" role="alert">
      {{ session('success') }}
      <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
   </div>
   @endif
   @if(session('error'))
   <div class="alert alert-danger alert-dismissible fade show" role="alert">
      {{ session('error') }}
      <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
   </div>
   @endif
   <section class="section">
      <div class="row">
         <div class="col-lg-12">
            <div class="card">
               <div class="card-body">
                  <h5 class="card-title">Blogs</h5>
                  <table class="table table datatable">
                     <thead>
                        <tr>
                           <th>#</th>
                           <th>Image</th>
                           <th>Title</th>
                           <th>Category</th>
                           <th>Status</th>
                           <th>Actions</th>
                        </tr>
                     </thead>
                     <tbody>
                        @foreach ($blogs as $blog)
                        <tr>
                           <td>{{ $blog->id }}</td>
                           <!-- Blog Image Column -->
                           <td>
                              @php
                              // Decode the JSON-encoded images array as an associative array
                              $images = json_decode($blog->images, true);
                              // Ensure $images is a valid array and contains at least one element
                              if (is_array($images) && isset($images[0])) {
                              $firstImage = asset('storage/' . $images[0]);
                              } else {
                              // Use a default image if $images is empty or invalid
                              $firstImage = asset('frontend/assets/img/latest-blog/l-blog-2.jpg');
                              }
                              @endphp
                              <!-- Display the first image -->
                              <img class="img-fluid" src="{{ $firstImage }}" alt="Blog Image" style="width: 50px; height: 50px; border-radius: 50%; object-fit: cover;">
                           </td>
                           <td>{{ $blog->title }}</td>
                           <td>{{ $blog->category->name ?? 'N/A' }}</td>
                           <td>
                              <form action="{{ route('blogs.updateStatus', $blog->id) }}" method="POST" style="display:inline;">
                                 @csrf
                                 @method('PUT')
                                 <button type="submit" class="btn btn-sm" style="border: none; background: none; padding: 5px 10px;">
                                 @if($blog->status == 'active')
                                 <span class="badge bg-success">Active</span>
                                 @else
                                 <span class="badge bg-danger">Inactive</span>
                                 @endif
                                 </button>
                              </form>
                           </td>
                           <td>
                              <a href="#" class="text-info" data-bs-toggle="modal" data-bs-target="#viewModal-{{ $blog->id }}" style="font-size: 24px; margin-right: 10px;">
                              <i class='bx bx-show' style='color:#009ef7; font-size:24px;'></i>
                              </a>
                              <!-- Edit Icon -->
                              <a href="{{ route('blogs.edit', $blog->id) }}" class="text-warning" style="font-size: 24px; margin-right: 10px;">
                              <i class='bx bx-edit' style='color:#29e718; font-size:24px;'></i>
                              </a>
                              <!-- Delete Icon -->
                              <form action="{{ route('blogs.destroy', $blog->id) }}" method="POST" style="display:inline;" onsubmit="return confirm('Are you sure you want to delete this blog?');">
                                 @csrf
                                 @method('DELETE')
                                 <button type="submit" class="btn btn-link text-danger" style="border: none; background: none;">
                                 <i class='bx bx-trash' style='color:red; font-size:24px;'></i>
                                 </button>
                              </form>
                           </td>
                        </tr>
                        <div class="modal fade" id="viewModal-{{ $blog->id }}" tabindex="-1" aria-labelledby="viewModalLabel" aria-hidden="true">
                           <div class="modal-dialog modal-lg">
                              <div class="modal-content">
                                 <div class="modal-header bg-gradient-info text-white">
                                    <h5 class="modal-title" id="viewModalLabel" style="color: black;">Blog Details</h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                 </div>
                                 <div class="modal-body">
                                    <div class="row">
                                       <div class="col-md-6">
                                          <h5><strong>Title:</strong></h5>
                                          <p>{{ $blog->title }}</p>
                                       </div>
                                       <div class="col-md-6">
                                          <h5><strong>Category:</strong></h5>
                                          <p>{{ $blog->category->name ?? 'N/A' }}</p>
                                       </div>
                                       <div class="col-md-6 mb-3">
                                          <h5><strong>Status:</strong></h5>
                                          <p>
                                             @if($blog->status == 'active')
                                             <span class="badge bg-success">Active</span>
                                             @else
                                             <span class="badge bg-danger">Inactive</span>
                                             @endif
                                          </p>
                                       </div>
                                       <div class="col-md-6">
                                          <h5><strong>Content:</strong></h5>
                                          <p>{!! Str::limit(strip_tags($blog->content), 100) !!}...</p>
                                       </div>
                                       @php
                                       // Decode the JSON-encoded images array as an associative array
                                       $images = json_decode($blog->images, true);
                                       // Ensure $images is a valid array and contains at least one element
                                       if (is_array($images) && isset($images[0])) {
                                       $firstImage = asset('storage/' . $images[0]);
                                       } else {
                                       // Use a default image if $images is empty or invalid
                                       $firstImage = asset('frontend/assets/img/latest-blog/l-blog-2.jpg');
                                       }
                                       @endphp
                                       <!-- Display the first image -->
                                       <img class="img-fluid" src="{{ $firstImage }}" alt="Blog Image" style="width:20%;">
                                    </div>
                                 </div>
                                 <div class="modal-footer">
                                    <button type="button" class="btn btn-outline-danger" data-bs-dismiss="modal">Close</button>
                                 </div>
                              </div>
                           </div>
                        </div>
                        @endforeach
                     </tbody>
                  </table>
               </div>
            </div>
         </div>
      </div>
   </section>
</main>
@endsection
@section('scripts')
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
<script>
   // Handle the button click to toggle status
   $('.btn').on('click', function(event) {
       event.preventDefault(); // Prevent default button submission
       var form = $(this).closest('form'); // Find the closest form to the button
       form.submit(); // Submit the form
   });
</script>
@endsection