@extends('backend.layouts.adminlayouts')

@section('content')
    <main id="main" class="main">

        <section class="section">
            <div class="row">

                <!-- Success and Error Alerts -->
                @if (session('success'))
                    <div class="alert alert-success alert-dismissible fade show" role="alert">
                        {{ session('success') }}
                        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert"
                            aria-label="Close"></button>
                    </div>
                @endif
                @if (session('error'))
                    <div class="alert alert-danger alert-dismissible fade show" role="alert">
                        {{ session('error') }}
                        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert"
                            aria-label="Close"></button>
                    </div>
                @endif

                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Update Carrear</h5>

                            <form id="quill-form" action="{{ route('admin.why_study_mbbs_abroad.update') }}" method="POST"
                                enctype="multipart/form-data">
                                @csrf

                                <!-- Content Field -->
                                <h5><b>Carrear Content</b></h5>
                                <div class="row mb-3">
                                    <div class="col-sm-12">
                                        <!-- Quill Editor Container -->
                                        <div id="quill-editor" class="quill-editor-full mb-3">{!! $setting->content ?? '' !!}</div>

                                        <!-- Hidden Textarea for Form Submission -->
                                        <textarea name="content" id="hidden-content" style="display: none;"
                                            class="form-control @error('content') is-invalid @enderror"></textarea>

                                        @error('content')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                    </div>
                                </div>

                                <!-- Image Field -->
                                <div class="row mb-3" style="margin-top: 10%">
                                    <label for="image1" class="col-sm-2 col-form-label">Image:</label>
                                    <div class="col-sm-10">
                                        <input type="file" class="form-control @error('image1') is-invalid @enderror"
                                            id="image1" name="image1" accept="image/*">
                                        @error('image1')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                        <!-- Preview Section -->
                                        <img id="image1_preview"
                                            src="{{ $setting->image1 ? asset('storage/' . $setting->image1) : '#' }}"
                                            alt="Image1 Preview"
                                            style="display: {{ $setting->image1 ? 'block' : 'none' }}; margin-top: 10px; max-width: 30%; height: auto;" />
                                    </div>
                                </div>

                                <!-- Submit Button -->
                                <div class="row mb-3">
                                    <div class="col-sm-10 offset-sm-2">
                                        <button type="submit" class="btn btn-primary">Update</button>
                                    </div>
                                </div>
                            </form>

                        </div>
                    </div>
                </div>
            </div>
        </section>

    </main>
@endsection

<script src="https://cdn.quilljs.com/1.3.7/quill.min.js"></script>
<link href="https://cdn.quilljs.com/1.3.7/quill.snow.css" rel="stylesheet">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>


<script>
    $(document).ready(function() {
        // Initialize Quill editor with full toolbar options
        var quill = new Quill('#quill-editor', {
            theme: 'snow',
            placeholder: 'Write content here...',
            modules: {
                toolbar: [
                    ['bold', 'italic'], // Bold and Italic
                    ['link', 'image'], // Link and Image
                    [{
                        'header': '1'
                    }, {
                        'header': '2'
                    }, {
                        'header': '3'
                    }, {
                        'header': '4'
                    }, {
                        'header': '5'
                    }, {
                        'header': '6'
                    }], // Headings h1 to h6
                    [{
                        'list': 'ordered'
                    }, {
                        'list': 'bullet'
                    }], // Ordered and Unordered List
                    ['blockquote', 'code-block'], // Blockquote and Code Block
                    [{
                        'align': []
                    }], // Align (left, center, right)
                    [{
                        'color': []
                    }, {
                        'background': []
                    }] // Text Color and Background
                ]
            }
        });

        // Handle form submission to save the content
        $(document).on('submit', '#quill-form', function() {
            var content = quill.root.innerHTML;
            $('#hidden-content').val(content);
        });

        // Handle Image Upload inside Quill Editor
        quill.getModule('toolbar').addHandler('image', function() {
            let input = document.createElement('input');
            input.setAttribute('type', 'file');
            input.setAttribute('accept', 'image/*');
            input.click();

            input.onchange = function() {
                let file = input.files[0];
                if (file) {
                    let reader = new FileReader();
                    reader.onload = function(e) {
                        let range = quill.getSelection();
                        quill.insertEmbed(range.index, 'image', e.target.result);
                    };
                    reader.readAsDataURL(file);
                }
            };
        });
    });

    // Image Preview for external file input (optional)
    document.addEventListener('DOMContentLoaded', function() {
        const imageInput = document.getElementById('image1');
        if (imageInput) {
            imageInput.addEventListener('change', function(event) {
                const file = event.target.files[0];
                const preview = document.getElementById('image1_preview');
                if (file) {
                    const reader = new FileReader();
                    reader.onload = function(e) {
                        preview.src = e.target.result;
                        preview.style.display = 'block'; // Show preview
                    };
                    reader.readAsDataURL(file);
                } else {
                    preview.style.display = 'none'; // Hide preview if no file selected
                }
            });
        }
    });
</script>
