@extends('backend.layouts.adminlayouts')

@section('content')

<main id="main" class="main">

    <div class="pagetitle-container">
        <div class="pagetitle float-left">
            <h1 style="color: black;">Category</h1> <!-- Added Inline CSS for Black Color -->
            <nav>
                <ol class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Home</a></li>
                    <li class="breadcrumb-item">Category</li>
                    <li class="breadcrumb-item active">Index</li>
                </ol>
            </nav>
        </div>
        <div class="button-container float-right">
            <a href="{{ route('categories.create') }}" class="btn-add-university">
                <i class='bx bx-add-to-queue' style="font-size: 24px;"></i> Add Category
            </a>
        </div>
    </div>

    <!-- Success and Error Alerts -->
    @if(session('success'))
    <div class="alert alert-success alert-dismissible fade show" role="alert">
        {{ session('success') }}
        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
    @endif
    @if(session('error'))
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
        {{ session('error') }}
        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
    @endif

    <table class="table table datatable">
        <thead>
            <tr>
                <th>#</th>
                <th>Name</th>
                <th>Status</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($categories as $category)
            <tr>
                <td>{{ $category->id }}</td>
                <td>{{ $category->name }}</td>
                <td>
                    <!-- Status Button with Color Change -->
                    <form action="{{ route('categories.updateStatus', $category->id) }}" method="POST" style="display:inline;">
                        @csrf
                        @method('PUT')

                        <!-- Button for Active/Inactive Status -->
                        <button type="submit" class="btn btn-sm" style="border: none; background: none; padding: 5px 10px;">
                            @if($category->status == 'active')
                            <!-- Green Button for Active -->
                            <span class="badge bg-success">Active</span>
                            @else
                            <!-- Red Button for Inactive -->
                            <span class="badge bg-danger">Inactive</span>
                            @endif
                        </button>
                    </form>
                </td>

                <td>
                    <!-- View Icon -->
                    <a href="#" class="text-info" data-bs-toggle="modal" data-bs-target="#viewModal-{{ $category->id }}" style="font-size: 24px; margin-right: 10px;">
                        <i class='bx bx-show' style='color:#009ef7; font-size:24px;'></i>
                    </a>

                    <!-- Edit Icon -->
                    <a href="{{ route('categories.edit', $category->id) }}" class="text-warning" style="font-size: 24px; margin-right: 10px;">
                        <i class='bx bx-edit' style='color:#29e718; font-size:24px;'></i>
                    </a>

                    <!-- Delete Icon -->
                    <form action="{{ route('categories.destroy', $category->id) }}" method="POST" style="display:inline;" onsubmit="return confirm('Are you sure you want to delete this category?');">
                        @csrf
                        @method('DELETE')
                        <button type="submit" class="btn btn-link text-danger" style="border: none; background: none;">
                            <i class='bx bx-trash' style='color:red; font-size:24px;'></i>
                        </button>
                    </form>
                </td>
            </tr>

            <!-- Modal for Viewing Category Details -->
            <div class="modal fade" id="viewModal-{{ $category->id }}" tabindex="-1" aria-labelledby="viewModalLabel" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header bg-gradient-info text-white">
                            <h5 class="modal-title" id="viewModalLabel" style="color: black;">Category Details</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                        </div>
                        <div class="modal-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <h5><strong>Name:</strong></h5>
                                    <p>{{ $category->name }}</p>
                                </div>
                                <div class="col-md-6">
                                    <h5><strong>Status:</strong></h5>
                                    <p>
                                        @if($category->status == 'active')
                                        <span class="badge bg-success">Active</span>
                                        @else
                                        <span class="badge bg-danger">Inactive</span>
                                        @endif
                                    </p>
                                </div>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-outline-danger" data-bs-dismiss="modal">Close</button>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Modal -->
            @endforeach
        </tbody>
    </table>

</main>

@endsection

@section('scripts')
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
<script>
    // Handle the button click to toggle status
    $('.btn').on('click', function(event) {
        event.preventDefault(); // Prevent default button submission
        var form = $(this).closest('form'); // Find the closest form to the button
        form.submit(); // Submit the form
    });
</script>
@endsection
