@extends('backend.layouts.adminlayouts')

@section('content')
    <main id="main" class="main">

        <section class="section">
            <div class="row">

                <!-- Success and Error Alerts -->
                @if (session('success'))
                    <div class="alert alert-success alert-dismissible fade show" role="alert">
                        {{ session('success') }}
                        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert"
                            aria-label="Close"></button>
                    </div>
                @endif
                @if (session('error'))
                    <div class="alert alert-danger alert-dismissible fade show" role="alert">
                        {{ session('error') }}
                        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert"
                            aria-label="Close"></button>
                    </div>
                @endif

                <div class="row">
                    <div class="col-lg-12">
                        <div class="card">
                            <div class="card-body">
                                <h5 class="card-title">Update Privacy & Policy</h5>

                                <form id="quill-form" action="{{ route('admin.updatePrivacy_policy') }}" method="POST"
                                    enctype="multipart/form-data">
                                    @csrf

                                    <div class="row mb-3">
                                        <div class="col-sm-10">
                                            <!-- Quill Editor Container -->
                                            <div id="quill-editor" class="quill-editor-full">{!! $setting->content ?? '' !!}</div>

                                            <!-- Hidden Textarea for Form Submission -->
                                            <textarea name="content" id="hidden-content" style="display: none;"
                                                class="form-control @error('content') is-invalid @enderror">
                                  
                                </textarea>

                                            @error('content')
                                                <div class="invalid-feedback">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>



                                    <!-- Submit Button -->
                                    <div class="row" style="margin-top: 10%;">
                                        <div class="col-sm-10 offset-sm-2">
                                            <button type="submit" class="btn btn-primary">Update Privacy & Policy


                                            </button>
                                        </div>
                                    </div>
                                </form>

                            </div>
                        </div>
                    </div>
                </div>
        </section>

    </main>
@endsection

<script>
    // Image1 preview script
    const image1Input = document.getElementById('image1');
    if (image1Input) {
        image1Input.addEventListener('change', function(event) {
            const file = event.target.files[0];
            if (file) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    const preview = document.getElementById('image1_preview');
                    preview.src = e.target.result;
                    preview.style.display = 'block';
                };
                reader.readAsDataURL(file);
            } else {
                document.getElementById('image1_preview').style.display = 'none';
            }
        });
    }

    // Image2 preview script
    const image2Input = document.getElementById('image2');
    if (image2Input) {
        image2Input.addEventListener('change', function(event) {
            const file = event.target.files[0];
            if (file) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    const preview = document.getElementById('image2_preview');
                    preview.src = e.target.result;
                    preview.style.display = 'block';
                };
                reader.readAsDataURL(file);
            } else {
                document.getElementById('image2_preview').style.display = 'none';
            }
        });
    }
</script>

<script src="https://cdn.quilljs.com/1.3.7/quill.min.js"></script>
<link href="https://cdn.quilljs.com/1.3.7/quill.snow.css" rel="stylesheet">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>



<script>
    $(document).ready(function() {
        var quill = new Quill('#quill-editor', {
            theme: 'snow',
            placeholder: 'Write content here...',
            modules: {
                toolbar: [
                    ['bold', 'italic'], // Bold and Italic
                    ['link', 'image'], // Link and Image
                    [{
                        'header': '1'
                    }, {
                        'header': '2'
                    }, {
                        'header': '3'
                    }, {
                        'header': '4'
                    }, {
                        'header': '5'
                    }, {
                        'header': '6'
                    }], // Headings h1 to h6
                    [{
                        'list': 'ordered'
                    }, {
                        'list': 'bullet'
                    }], // Ordered and Unordered List
                    ['blockquote', 'code-block'], // Blockquote and Code Block
                    [{
                        'align': []
                    }], // Align (left, center, right)
                    [{
                        'color': []
                    }, {
                        'background': []
                    }] // Text Color and Background
                ]
            }
        });

        $(document).on('submit', '#quill-form', function() {
            var content = quill.root.innerHTML;
            $('#hidden-content').val(content);
        });
    });
</script>
