@extends('backend.layouts.adminlayouts')

@section('content')

<main id="main" class="main">

@if(session('error'))
<div class="alert alert-danger alert-dismissible fade show" role="alert">
    {{ session('error') }}
    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
</div>
@endif
<section class="section">
    <div class="row">
        <div class="col-lg-12">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">Edit Testimonial</h5>

                    <form action="{{ route('admin.testimonials.update', $testimonial->id) }}" method="POST" enctype="multipart/form-data">
                        @csrf
                        @method('PUT')

                        <!-- Name Field -->
                        <div class="row mb-3">
                            <label for="name" class="col-sm-2 col-form-label">Testimonial Name:</label>
                            <div class="col-sm-10">
                                <input type="text" class="form-control" id="name" name="name" value="{{ $testimonial->name }}" required>
                            </div>
                        </div>

                        <!-- Image Field -->
                        <div class="row mb-3">
                            <label for="image" class="col-sm-2 col-form-label">Testimonial Image:</label>
                            <div class="col-sm-10">
                                <input type="file" class="form-control" id="image" name="image" accept="image/*" onchange="previewImage(event)">
                                
                                <!-- Display Existing Image if any -->
                                @if($testimonial->image)
                                    <div class="mt-2">
                                        <img src="{{ asset('storage/' . $testimonial->image) }}" width="100" class="mt-2" id="image-preview">
                                    </div>
                                @else
                                    <p>No image uploaded yet.</p>
                                @endif
                            </div>
                        </div>

                        <!-- Paragraph Field -->
                        <div class="row mb-3">
                            <label for="paragraph" class="col-sm-2 col-form-label">Testimonial Paragraph:</label>
                            <div class="col-sm-10">
                                <textarea class="form-control" id="paragraph" name="paragraph" required>{{ $testimonial->paragraph }}</textarea>
                            </div>
                        </div>

                        <!-- Submit Button -->
                        <div class="row mb-3">
                            <div class="col-sm-10 offset-sm-2">
                                <button type="submit" class="btn btn-primary">Update</button>
                            </div>
                        </div>
                    </form>

                </div>
            </div>
        </div>
    </div>
</section>

</main>

@endsection

@section('scripts')
<script>
    // JavaScript function to preview image
    function previewImage(event) {
        var reader = new FileReader();
        reader.onload = function() {
            var output = document.getElementById('image-preview');
            output.src = reader.result;
            output.style.width = "100px"; // Set the width of the preview image
            output.style.marginTop = "10px"; // Set the margin for better spacing
        }
        reader.readAsDataURL(event.target.files[0]); // Read the uploaded image
    }
</script>
@endsection
