@extends('backend.layouts.adminlayouts')

@section('content')

<main id="main" class="main">

    <div class="pagetitle-container">
        <div class="pagetitle float-left">
            <h1>Testimonials</h1>
            <nav>
                <ol class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Home</a></li>
                    <li class="breadcrumb-item">Testimonials</li>
                    <li class="breadcrumb-item active">Index</li>
                </ol>
            </nav>
        </div>
        <div class="button-container float-right">
            <a href="{{ route('admin.testimonials.create') }}" class="btn-add-university">
                <i class='bx bx-add-to-queue' style="font-size: 24px;"></i> Add Testimonials
            </a>
        </div>
    </div>

    <!-- Success and Error Alerts -->
    @if(session('success'))
    <div class="alert alert-success alert-dismissible fade show" role="alert">
        {{ session('success') }}
        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
    @endif
    @if(session('error'))
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
        {{ session('error') }}
        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
    @endif

    <!-- Testimonials Table -->
    <table class="table table datatable">
        <thead>
            <tr>
                <th>#</th>
                <th>Name</th>
                <th>Paragraph</th>
                <th>Image</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            @foreach($testimonials as $testimonial)
            <tr>
                <td>{{ $loop->iteration }}</td>
                <td>{{ $testimonial->name }}</td>
                <td>{{ Str::limit($testimonial->paragraph, 50) }}</td>
                <td>
                    <img src="{{ asset('storage/' . $testimonial->image) }}" alt="Image" style="width: 50px; height: 50px; border-radius: 50%; object-fit: cover;">
                </td>
                <td>
                    <!-- View Icon -->
                    <a href="#" class="text-info" data-bs-toggle="modal" data-bs-target="#viewModal-{{ $testimonial->id }}" style="font-size: 24px; margin-right: 10px;">
                        <i class='bx bx-show' style='color:#007bff; font-size:24px;'></i>
                    </a>
                    
                    <!-- Edit Icon -->
                    <a href="{{ route('admin.testimonials.edit', $testimonial->id) }}" class="text-warning" style="font-size: 24px; margin-right: 10px;">
                        <i class='bx bx-edit' style='color:#29e718; font-size:24px;'></i>
                    </a>
                    
                    <!-- Delete Icon -->
                    <form action="{{ route('admin.testimonials.destroy', $testimonial->id) }}" method="POST" style="display:inline;" onsubmit="return confirm('Are you sure you want to delete this testimonial?');">
                        @csrf
                        @method('DELETE')
                        <button type="submit" class="btn btn-link text-danger" style="border: none; background: none;">
                            <i class='bx bx-trash' style='color:red; font-size:24px;'></i>
                        </button>
                    </form>
                </td>
            </tr>

            <!-- View Modal -->
            <div class="modal fade" id="viewModal-{{ $testimonial->id }}" tabindex="-1" aria-labelledby="viewModalLabel" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header bg-gradient-info text-white">
                            <h5 class="modal-title" id="viewModalLabel" style="color: black">Testimonial Details</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                        </div>
                        <div class="modal-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <h5><strong>Name:</strong></h5>
                                    <p>{{ $testimonial->name }}</p>
                                </div>
                                <div class="col-md-6">
                                    <h5><strong>Paragraph:</strong></h5>
                                    <p>{{ $testimonial->paragraph }}</p>
                                </div>
                                <div class="col-md-6">
                                    <h5><strong>Image:</strong></h5>
                                    <img src="{{ asset('storage/' . $testimonial->image) }}" class="img-fluid" style="max-width: 50%;" />
                                </div>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-outline-danger" data-bs-dismiss="modal">Close</button>
                        </div>
                    </div>
                </div>
            </div>
            @endforeach
        </tbody>
    </table>

</main>

@endsection
